/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : Dec. 2006

 File          : WakeUpTimer.c

 Hardware      : Applicable to ADuC703x

 Description   : Wake-up Timer causes part to power-up every 8s.
 				 the timer is configured in Hr:Min:Sec:Hundredths format

				 T2LD:
				 bits 31-24 represent the hours
				 bits 21-16 represent the minutes
				 bits 13-8 represent the secondes
				 bits 6-0 represent the hundredths

				 The debugger cannot be used when the part is placed in power down mode.
		
*********************************************************************/

#include <ADuC7033.h>

void My_IRQ_Function(void);

int main()
{
	IRQ = My_IRQ_Function;
	IRQEN = 0x010;						// Enable T2 (Wake-up Timer) to generate an interrupt
	GP2DAT = 0x02000000;
	T2LD = 0x800;						// Wait x seconds in power down mode
	T2VAL = 0x800;
	T2CON = 0x2E8;						// Clock Source - Low Power Oscilator
										// Count down, Enable Timer 2, hours mode
	while(1){}							// Infinite Loop
}

void My_IRQ_Function() 
{
	int iIRQ_Source;
	unsigned long it1=1234, it2=4321;
	iIRQ_Source = IRQSTA;				// Save a temporary copy of IRQSTA
  	if ((iIRQ_Source & 0x010)!=0)
	{
		GP2DAT ^=0x020000;					// Complement P2.1
		T2CLRI = 0x01;					// restart Timer 2
		POWKEY0 = 0x01;		 			// Put all peripherals, PLL and Core Asleep
		POWCON  = 0x00;			
		POWKEY1 = 0xF4;
		it1 = it1*it2;					// Dummy cycle to ensure correct power down
	}	 	
	return ;
}
